
[![Python Versions](https://img.shields.io/pypi/pyversions/perovskite.svg)](https://pypi.org/project/perovskite/)
![pypi Versions](https://badge.fury.io/py/perovskite.svg)

Perovskite
----------------------
Welcome to Perovskite.

This is one tool to generator perovskite structures for calculation, such as First-principles calculations.

Quick Install
----------------------

```bash
pip install perovskite
```

License
----------------------
BSD-3-Clause License

Contact
----------------------
Developer: Boliqq07: 986798607@qq.com




